#include "plib.h"

/* ===============================
 * METHODS used for the two Servos
 * ===============================
 * Frequency is 50Hz, or 20msec period.
 * PWM duty cycles range from 550 - 2450 microseconds
 */

/*
   * Let x = degrees; Let 1 be the NEUTRAL 0 degree point.
   * This method takes in values from -90 to 90, using the number 1 as degree 0.
   * It rotates 1 by x degrees. So if x is -90, then 1 will end up on the left 
   * and 2 will be on top. If x is 90, then 1 will end up on the right and 4 
   * will be on top.
   * Output takes values 1 or 2, signifying OC1 or OC2
*/
void rotate(double degrees, int output) {
  /*
   * -90 degrees: 550 micro = 0.55 milliseconds
   * 0 degrees: 1500 micro = 1.5 milliseconds
   * 90 degrees: 2450 micro = 2.45 milliseconds
  */
  double duty_cycle = 50000.0 * (0.95 * (degrees / 90.0) + 1.5) / 20.0;
  if (output == 1) SetDCOC1PWM(duty_cycle);
  else SetDCOC2PWM(duty_cycle);
}
